summaryrefslogtreecommitdiffstats
path: root/kexi/widget/tableview/kexicelleditorfactory.h
diff options
context:
space:
mode:
Diffstat (limited to 'kexi/widget/tableview/kexicelleditorfactory.h')
-rw-r--r--kexi/widget/tableview/kexicelleditorfactory.h24
1 files changed, 12 insertions, 12 deletions
diff --git a/kexi/widget/tableview/kexicelleditorfactory.h b/kexi/widget/tableview/kexicelleditorfactory.h
index 1b68cb8d..26b48bb6 100644
--- a/kexi/widget/tableview/kexicelleditorfactory.h
+++ b/kexi/widget/tableview/kexicelleditorfactory.h
@@ -20,8 +20,8 @@
#ifndef KEXICELLEDITORFACTORY_H
#define KEXICELLEDITORFACTORY_H
-#include <qvariant.h>
-#include <qwidget.h>
+#include <tqvariant.h>
+#include <tqwidget.h>
#include <kexidb/field.h>
@@ -44,17 +44,17 @@ class KEXIDATATABLE_EXPORT KexiCellEditorFactory
Once registered, \a item object will be owned by the factory, so you shouldn't
care about deleting it. */
static void registerItem( KexiCellEditorFactoryItem& item, uint type,
- const QString& subType = QString::null );
+ const TQString& subType = TQString() );
/*! \return item for \a type and (optional) \a subType.
If no item found, the one with empty subtype is tried.
If still no item found, the default is tried. Eventually, may return NULL. */
- static KexiCellEditorFactoryItem* item( uint type, const QString& subType = QString::null );
+ static KexiCellEditorFactoryItem* item( uint type, const TQString& subType = TQString() );
-// static KexiTableEdit* createEditor(KexiDB::Field &f, QScrollView* parent = 0);
- /*! Creates a new editor for \a column. If \a parent is of QScrollView, the new editor
- will be created inside parent->viewport() instead. */
- static KexiTableEdit* createEditor(KexiTableViewColumn &column, QWidget* parent = 0);
+// static KexiTableEdit* createEditor(KexiDB::Field &f, TQScrollView* tqparent = 0);
+ /*! Creates a new editor for \a column. If \a tqparent is of TQScrollView, the new editor
+ will be created inside tqparent->viewport() instead. */
+ static KexiTableEdit* createEditor(KexiTableViewColumn &column, TQWidget* tqparent = 0);
protected:
static void init();
@@ -66,13 +66,13 @@ class KEXIDATATABLE_EXPORT KexiCellEditorFactoryItem
public:
KexiCellEditorFactoryItem();
virtual ~KexiCellEditorFactoryItem();
- QString className() { return m_className; }
+ TQString className() { return m_className; }
protected:
-// virtual KexiTableEdit* createEditor(KexiDB::Field &f, QScrollView* parent = 0) = 0;
- virtual KexiTableEdit* createEditor(KexiTableViewColumn &column, QWidget* parent = 0) = 0;
+// virtual KexiTableEdit* createEditor(KexiDB::Field &f, TQScrollView* tqparent = 0) = 0;
+ virtual KexiTableEdit* createEditor(KexiTableViewColumn &column, TQWidget* tqparent = 0) = 0;
- QString m_className;
+ TQString m_className;
friend class KexiCellEditorFactory;
};